==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/hu/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Információ</strong>',
  '<strong>Profile</strong> Permissions' => '<strong>Profil</strong> jogosultságok',
  '<strong>Settings</strong> and Configuration' => '<strong>Beállítások</strong> és konfiguráció',
  '<strong>User</strong> administration' => '<strong>Felhasználó</strong> adminisztráció',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong> Figyelmeztetés: </strong> Minden jogosultság és profil beállítás visszaáll az alapértelmezett értékekre!',
  'Accept user: <strong>{displayName}</strong> ' => 'Következő felhasználó elfogadása: <strong>{displayName}</strong>',
  'Account' => 'Fiók',
  'Account Request for \'{displayName}\' has been approved.' => 'A(z) \'{displayName}\' fiókra vonatkozó kérelem jóváhagyásra került.',
  'Account Request for \'{displayName}\' has been declined.' => 'A \'{displayName}\' fiókra vonatkozó kérés elutasítva.',
  'Actions' => 'Tevékenység',
  'Active users' => 'Aktív felhasználók',
  'Add Groups...' => 'Csoportok hozzáadása',
  'Add new category' => 'Új kategória hozzáadása',
  'Add new field' => 'Új mező hozzáadása',
  'Add new group' => 'Új csoport hozzáadása',
  'Add new members...' => 'Új tagok hozzáadása',
  'Add new user' => 'Új felhasználó hozzáadása',
  'Administrator group could not be deleted!' => 'Az adminisztrátor csoportot nem lehet törölni!',
  'All open registration invitations were successfully deleted.' => 'Minden nyitott regisztrációs kérés sikeresen törölve lett.',
  'All the personal data of this user will be irrevocably deleted.' => 'A felhasználó összes személyes adata visszavonhatatlanul törölve lesz.',
  'Allow' => 'Elfogad',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => 'Engedélyezi a felhasználóknak egyéni jogosultságok beállítását a profiljukhoz?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Engedélyezze a nem hitelesített felhasználók (vendégek) korlátozott hozzáférését',
  'Applied to new or existing users without any other group membership.' => 'Új vagy meglévő felhasználókra alkalmazza bármilyen csoporttagság nélkül.',
  'Apply' => 'Alkalmaz',
  'Approve' => 'Elfogadás',
  'Approve all selected' => '',
  'Are you really sure that you want to disable this user?' => 'Biztos vagy benne, hogy letiltod ezt a felhasználót?',
  'Are you really sure that you want to enable this user?' => 'Biztos vagy benne, hogy engedélyezed ezt a felhasználót?',
  'Are you really sure that you want to impersonate this user?' => 'Biztos vagy benne, hogy meg akarod személyesíteni ezt a felhasználót?',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => '',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Tényleg biztos vagy benne? Azok a felhasználók, akik nincsenek hozzárendelve egy másik csoporthoz, automatikusan az alapértelmezett csoporthoz lesznek rendelve.',
  'Are you sure that you want to delete following user?' => 'Biztosan törölni akarod a következő felhasználót?',
  'Cancel' => 'Mégsem',
  'Click here to review' => 'Kattints ide az ellenőrzéshez',
  'Confirm user deletion' => 'A felhasználó törlésének megerősítése',
  'Could not load category.' => 'Kategória betöltése sikertelen.',
  'Create new group' => 'Új csoport létrehozása',
  'Create new profile category' => 'Új profil-kategória létrehozása',
  'Create new profile field' => 'Új profil-mező létrehozása',
  'Deactivate' => 'Deaktivál',
  'Deactivate individual profile permissions?' => 'Deaktiválja az egyes profilengedélyeket?',
  'Decline' => 'Nem vesz részt',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Következő felhasználó elutasítása és törlése: <strong>{displayName}</strong>',
  'Decline all selected' => '',
  'Default' => 'Alapértelmezett',
  'Default Profile Permissions' => 'Alapértelmezett profilengedélyek',
  'Default Sorting' => '',
  'Default content of the registration approval email' => 'A regisztrációt jóváhagyó e-mail alapértelmezett tartalma',
  'Default content of the registration denial email' => 'A regisztrációt elutasító e-mail alapértelmezett tartalma',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Felhasználói tétlenség miatti időtúllépés, automatikus kijelentkezés alapértelmezett  időtartama (másodpercben, opcionális)',
  'Default user profile visibility' => 'Felhasználói profil láthatóságának alapértelmezése',
  'Delete' => 'Törlés',
  'Delete All' => 'Mindet törli',
  'Delete all contributions of this user' => 'Törölje a felhasználó összes hozzájárulását',
  'Delete invitation' => 'Meghívás törlése',
  'Delete invitation?' => 'Meghívó törlése?',
  'Delete spaces which are owned by this user' => 'A felhasználó tulajdonát képező közösségek törlése',
  'Deleted invitation' => 'Törölt meghívás',
  'Deleted users' => 'Törölt felhasználók',
  'Disable' => 'Kikapcsolás',
  'Disabled' => 'Kikapcsolva',
  'Disabled users' => 'Letiltott felhasználók',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Ne módosítsd az olyan helykitöltőket, mint {displayName}, ha azt szeretnéd, hogy a rendszer automatikusan kitöltse őket. Ha az email tartalmát a rendszer alapértelmezett beállítására szeretnéd visszaállítani, hagyd őket üresen.',
  'Edit' => 'Szerkesztés',
  'Edit category' => 'Kategória szerkesztése',
  'Edit profile category' => 'Profil-kategória szerkesztése',
  'Edit profile field' => 'Profil-mező szerkesztése',
  'Edit user: {name}' => 'Felhasználó szerkesztése: {name}',
  'Enable' => 'Engedélyezés',
  'Enable individual profile permissions' => 'Bekapcsolja az egyéni profilengedélyeket',
  'Enabled' => 'Bekapcsolva',
  'First name' => 'Utónév',
  'Group Manager' => 'Csoportkezelő',
  'Group not found!' => 'A csoport nem található!',
  'Group user not found!' => 'A csoport  felhasználója nem található!',
  'Groups' => 'Csoportok',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => 'Itt profil-kategóriákat és mezőket hozhatsz létre vagy szerkeszthetsz.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Ha az egyedi profilengedélyek nem engedélyezettek, akkor a következő beállítások nem módosíthatók minden felhasználó számára. Ha egyedi profilengedélyek engedélyezettek, akkor a beállításokat csak alapértelmezettként lesznek beállítva, amelyeket a felhasználók testre szabhatnak. Ezután a következő bejegyzések ugyanabban a formában jelennek meg a felhasználói profil beállításaiban:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Ha ezt az opciót nem választod ki, akkor a közösségek tulajdonjoga átkerül a fiókodba.',
  'Impersonate' => 'Megszemélyesítés',
  'Include captcha in registration form' => 'Captcha megjelenítése a regisztrációs űrlapon',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => 'A meghívás nem található!',
  'Last login' => 'Utolsó bejelentkezés',
  'Last name' => 'Vezetéknév',
  'List pending registrations' => 'Folyamatban lévő regisztrációk listázása',
  'Make the group selectable at registration.' => 'Tegye a csoportot a regisztráció során választhatóvá.',
  'Manage group: {groupName}' => 'Csoport kezelése: {groupName}',
  'Manage groups' => 'Csoportok kezelése',
  'Manage profile attributes' => 'Profil attribútumok kezelése',
  'Member since' => 'Tagság kezdete',
  'Members' => 'Tagok',
  'Members can invite external users by email' => 'A tagok meghívhatnak külső felhasználókat e-mailben',
  'Message' => 'Üzenet',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'A minimális érték 20 másodperc. Ha nincs beállítva, a munkamenet időtúllépés 1400 másodperc (24 perc) elteltével történik meg, a tevékenységtől függetlenül (alapértelmezett munkamenet időtúllépés) időtúllépés)',
  'New approval requests' => 'Új jóváhagyási kérelmek',
  'New users can register' => 'Új felhasználók is regisztrálhatnak',
  'No' => 'Nem',
  'No users were selected.' => '',
  'No value found!' => 'Nem található adat!',
  'None' => 'Nincs',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => 'Egy vagy több felhasználónak szüksége van a jóváhagyásodra, mint csoport admin.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Csak akkor alkalmazható, ha engedélyezett a korlátozott hozzáférés a nem hitelesített felhasználók számára. Csak az új felhasználókra vonatkozik.',
  'Overview' => 'Tartalomjegyzék',
  'Password' => 'Jelszó',
  'Pending approvals' => 'Függő jóváhagyások',
  'Pending user approvals' => 'Függőben lévő felhasználó-jóváhagyások',
  'People' => 'Emberek',
  'Permanently delete' => 'Törölje véglegesen',
  'Permissions' => 'Engedélyek',
  'Prioritised User Group' => '',
  'Profile Permissions' => 'Profilengedélyek',
  'Profiles' => 'Profilok',
  'Protected' => 'Védett',
  'Protected group can not be deleted!' => '',
  'Remove from group' => 'Eltávolítás a csoportból',
  'Require group admin approval after registration' => 'A regisztráció után kérje a csoport adminjának engedélyét',
  'Resend invitation email' => 'Meghívó e-mail újraküldése',
  'Save' => 'Mentés',
  'Search by name, email or id.' => 'Keresés név, email vagy azonosító szerint.',
  'Select Groups' => 'Csoportok kiválasztása',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select the profile fields you want to add as columns' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Küldés és elutasítás',
  'Send & save' => 'Küldés és mentés',
  'Send invitation email' => 'Meghívó e-mail küldése',
  'Send invitation email again?' => 'Meghívólevél újraküldése?',
  'Send invite' => 'Meghívás',
  'Send notifications to users when added to or removed from the group.' => 'Értesítéseket küldése a felhasználóknak, ha felveszik őket a csoportba vagy eltávolítják őket.',
  'Settings' => 'Beállítások',
  'Show group selection at registration' => 'Csoportválasztás megjelenítése a regisztrációkor',
  'Subject' => 'Téma',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Az összes csoporttag területi tagsága frissül. Ez akár néhány percet igénybe vehet.',
  'The following list contains all pending sign-ups and invites.' => 'Az alábbi lista tartalmazza az összes folyamatban lévő feliratkozást és meghívást.',
  'The following list contains all registered users awaiting an approval.' => 'Az alábbi lista tartalmazza a jóváhagyásra váró regisztrált felhasználókat.',
  'The registration was approved and the user was notified by email.' => '',
  'The registration was declined and the user was notified by email.' => '',
  'The registrations were approved and the users were notified by email.' => '',
  'The registrations were declined and the users were notified by email.' => '',
  'The selected invitations have been successfully deleted!' => 'A kiválasztott meghívókat sikeresen töröltük!',
  'The user is the owner of these spaces:' => 'A felhasználó tulajdonosa ezeknek a közösségeknek:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Ez az opció lehetővé teszi annak meghatározását, hogy a felhasználók beállíthatnak-e egyedi engedélyeket a saját profiljukhoz.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Ez az áttekintés tartalmazza az egyes regisztrált felhasználók listáját, a következő opciókkal: felhasználó megtekintése, felhasználó szerkesztése, felhasználó törlése.',
  'This user owns no spaces.' => 'Ez a felhasználó nem tulajdonosa egyetlen közösségnek sem.',
  'Unapproved' => 'Nincs elfogadva',
  'User deletion process queued.' => 'A felhasználó törlési folyamata sorban áll.',
  'User is already a member of this group.' => 'A felhasználó már tagja ennek a csoportnak',
  'User not found!' => 'A felhasználó nem található!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'A felhasználók különböző csoportokhoz (pl. csapatok, osztályok stb.) rendelhetők,  amelyek saját szabványos közösségekkel, csoport adminokkal és engedélyekkel rendelkeznek.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Ennek az opciónak a használatával visszavonhatatlanul törlődnek a felhasználó hozzájárulásai (például tartalmai, megjegyzései vagy kedvelései).',
  'View profile' => 'Profil törlése',
  'Visible for members only' => 'Csak a tagok számára látható',
  'Visible for members+guests' => 'A tagok és vendégek számára is látható',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => 'Igen',
  'You can only delete empty categories!' => 'Csak üres kategóriák törölhetők!',
  'You cannot delete yourself!' => 'Nem törölheted saját magad!',
  'never' => 'soha',
);

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/admin/messages/hu/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Információ</strong>',
  '<strong>Profile</strong> Permissions' => '<strong>Profil</strong> jogosultságok',
  '<strong>Settings</strong> and Configuration' => '<strong>Beállítások</strong> és konfiguráció',
  '<strong>User</strong> administration' => '<strong>Felhasználó</strong> adminisztráció',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong> Figyelmeztetés: </strong> Minden jogosultság és profil beállítás visszaáll az alapértelmezett értékekre!',
  'About the account request for \'{displayName}\'.' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'Következő felhasználó elfogadása: <strong>{displayName}</strong>',
  'Account' => 'Fiók',
  'Account Request for \'{displayName}\' has been approved.' => 'A(z) \'{displayName}\' fiókra vonatkozó kérelem jóváhagyásra került.',
  'Account Request for \'{displayName}\' has been declined.' => 'A \'{displayName}\' fiókra vonatkozó kérés elutasítva.',
  'Actions' => 'Tevékenység',
  'Active users' => 'Aktív felhasználók',
  'Add Groups...' => 'Csoportok hozzáadása',
  'Add new category' => 'Új kategória hozzáadása',
  'Add new field' => 'Új mező hozzáadása',
  'Add new group' => 'Új csoport hozzáadása',
  'Add new members...' => 'Új tagok hozzáadása',
  'Add new user' => 'Új felhasználó hozzáadása',
  'Administrator group could not be deleted!' => 'Az adminisztrátor csoportot nem lehet törölni!',
  'All open registration invitations were successfully deleted.' => 'Minden nyitott regisztrációs kérés sikeresen törölve lett.',
  'All the personal data of this user will be irrevocably deleted.' => 'A felhasználó összes személyes adata visszavonhatatlanul törölve lesz.',
  'Allow' => 'Elfogad',
  'Allow users to block each other' => 'A felhasználók letilthatják egymást',
  'Allow users to set individual permissions for their own profile?' => 'Engedélyezi a felhasználóknak egyéni jogosultságok beállítását a profiljukhoz?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Engedélyezze a nem hitelesített felhasználók (vendégek) korlátozott hozzáférését',
  'Applied to new or existing users without any other group membership.' => 'Új vagy meglévő felhasználókra alkalmazza bármilyen csoporttagság nélkül.',
  'Apply' => 'Alkalmaz',
  'Approve' => 'Elfogadás',
  'Approve all selected' => 'Az összes kiválasztott jóváhagyása',
  'Are you really sure that you want to disable this user?' => 'Biztos vagy benne, hogy letiltod ezt a felhasználót?',
  'Are you really sure that you want to enable this user?' => 'Biztos vagy benne, hogy engedélyezed ezt a felhasználót?',
  'Are you really sure that you want to impersonate this user?' => 'Biztos vagy benne, hogy meg akarod személyesíteni ezt a felhasználót?',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => 'Biztos vagy benne? A kiválasztott felhasználókat jóváhagyjuk és e-mailben értesítjük.',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => 'Biztos vagy benne? A kiválasztott felhasználók törlésre kerülnek, és e-mailben értesítést kapnak.',
  'Are you really sure? The selected users will be notified by e-mail.' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Tényleg biztos vagy benne? Azok a felhasználók, akik nincsenek hozzárendelve egy másik csoporthoz, automatikusan az alapértelmezett csoporthoz lesznek rendelve.',
  'Are you sure that you want to delete following user?' => 'Biztosan törölni akarod a következő felhasználót?',
  'Cancel' => 'Mégsem',
  'Click here to review' => 'Kattints ide az ellenőrzéshez',
  'Confirm user deletion' => 'A felhasználó törlésének megerősítése',
  'Could not approve the user!' => 'Nem sikerült jóváhagyni a felhasználót!',
  'Could not decline the user!' => 'Nem sikerült elutasítani a felhasználót!',
  'Could not load category.' => 'Kategória betöltése sikertelen.',
  'Could not send the message to the user!' => '',
  'Create new group' => 'Új csoport létrehozása',
  'Create new profile category' => 'Új profil-kategória létrehozása',
  'Create new profile field' => 'Új profil-mező létrehozása',
  'Deactivate individual profile permissions?' => 'Deaktiválja az egyes profilengedélyeket?',
  'Decline' => 'Nem vesz részt',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Következő felhasználó elutasítása és törlése: <strong>{displayName}</strong>',
  'Decline all selected' => 'Az összes kiválasztott elutasítása',
  'Default' => 'Alapértelmezett',
  'Default Profile Permissions' => 'Alapértelmezett profilengedélyek',
  'Default Sorting' => 'Alapértelmezett rendezés',
  'Default content of the email when sending a message to the user' => '',
  'Default content of the registration approval email' => 'A regisztrációt jóváhagyó e-mail alapértelmezett tartalma',
  'Default content of the registration denial email' => 'A regisztrációt elutasító e-mail alapértelmezett tartalma',
  'Default group can not be deleted!' => 'Az alapértelmezett csoport nem törölhető!',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Felhasználói tétlenség miatti időtúllépés, automatikus kijelentkezés alapértelmezett  időtartama (másodpercben, opcionális)',
  'Default user profile visibility' => 'Felhasználói profil láthatóságának alapértelmezése',
  'Delete' => 'Törlés',
  'Delete All' => 'Mindet törli',
  'Delete all contributions of this user' => 'Törölje a felhasználó összes hozzájárulását',
  'Delete invitation' => 'Meghívás törlése',
  'Delete invitation?' => 'Meghívó törlése?',
  'Delete spaces which are owned by this user' => 'A felhasználó tulajdonát képező közösségek törlése',
  'Deleted' => 'Törölve',
  'Deleted invitation' => 'Törölt meghívás',
  'Deleted users' => 'Törölt felhasználók',
  'Disable' => 'Kikapcsolás',
  'Disabled' => 'Kikapcsolva',
  'Disabled users' => 'Letiltott felhasználók',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Ne módosítsd az olyan helykitöltőket, mint {displayName}, ha azt szeretnéd, hogy a rendszer automatikusan kitöltse őket. Ha az email tartalmát a rendszer alapértelmezett beállítására szeretnéd visszaállítani, hagyd őket üresen.',
  'Edit' => 'Szerkesztés',
  'Edit category' => 'Kategória szerkesztése',
  'Edit profile category' => 'Profil-kategória szerkesztése',
  'Edit profile field' => 'Profil-mező szerkesztése',
  'Edit user: {name}' => 'Felhasználó szerkesztése: {name}',
  'Email all selected' => '',
  'Enable' => 'Engedélyezés',
  'Enable individual profile permissions' => 'Bekapcsolja az egyéni profilengedélyeket',
  'Enabled' => 'Bekapcsolva',
  'First name' => 'Utónév',
  'Group Manager' => 'Csoportkezelő',
  'Group not found!' => 'A csoport nem található!',
  'Group user not found!' => 'A csoport  felhasználója nem található!',
  'Groups' => 'Csoportok',
  'Hello {displayName},

Your account creation is under review.
Could you tell us the motivation behind your registration?

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => 'Kedves {displayName}! Fiókod aktiváltuk. Kattints ide a bejelentkezéshez: {loginUrl} Üdvözlettel: {AdminName}',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => 'Kedves {displayName}! Fiókkérelmed elutasították. Üdvözlettel: {AdminName}',
  'Here you can create or edit profile categories and fields.' => 'Itt profil-kategóriákat és mezőket hozhatsz létre vagy szerkeszthetsz.',
  'Hide online status of users' => 'A felhasználók online állapotának elrejtése',
  'If enabled, the Group Manager will need to approve registration.' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Ha az egyedi profilengedélyek nem engedélyezettek, akkor a következő beállítások nem módosíthatók minden felhasználó számára. Ha egyedi profilengedélyek engedélyezettek, akkor a beállításokat csak alapértelmezettként lesznek beállítva, amelyeket a felhasználók testre szabhatnak. Ezután a következő bejegyzések ugyanabban a formában jelennek meg a felhasználói profil beállításaiban:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Ha ezt az opciót nem választod ki, akkor a közösségek tulajdonjoga átkerül a fiókodba.',
  'Impersonate' => 'Megszemélyesítés',
  'Include captcha in registration form' => 'Captcha megjelenítése a regisztrációs űrlapon',
  'Information 1' => 'Információ 1',
  'Information 2' => 'Információ 2',
  'Information 3' => 'Információ 3',
  'Invisible' => 'Láthatatlan',
  'Invite new people' => 'Hívjon meg új embereket',
  'Invite not found!' => 'A meghívás nem található!',
  'Last login' => 'Utolsó bejelentkezés',
  'Last name' => 'Vezetéknév',
  'List pending registrations' => 'Folyamatban lévő regisztrációk listázása',
  'Make the group selectable at registration.' => 'Tegye a csoportot a regisztráció során választhatóvá.',
  'Manage group: {groupName}' => 'Csoport kezelése: {groupName}',
  'Manage groups' => 'Csoportok kezelése',
  'Manage profile attributes' => 'Profil attribútumok kezelése',
  'Member since' => 'Tagság kezdete',
  'Members' => 'Tagok',
  'Members can invite external users by email' => 'A tagok meghívhatnak külső felhasználókat e-mailben',
  'Members can invite external users by link' => 'A tagok külső felhasználókat hívhatnak meg linken keresztül',
  'Message' => 'Üzenet',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'A minimális érték 20 másodperc. Ha nincs beállítva, a munkamenet időtúllépés 1400 másodperc (24 perc) elteltével történik meg, a tevékenységtől függetlenül (alapértelmezett munkamenet időtúllépés) időtúllépés)',
  'New approval requests' => 'Új jóváhagyási kérelmek',
  'New users can register' => 'Új felhasználók is regisztrálhatnak',
  'No' => 'Nem',
  'No users were selected.' => 'Nincsenek kiválasztott felhasználók.',
  'No value found!' => 'Nem található adat!',
  'None' => 'Nincs',
  'Not visible' => 'Nem látható',
  'One or more user needs your approval as group admin.' => 'Egy vagy több felhasználónak szüksége van a jóváhagyásodra, mint csoport admin.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Csak akkor alkalmazható, ha engedélyezett a korlátozott hozzáférés a nem hitelesített felhasználók számára. Csak az új felhasználókra vonatkozik.',
  'Overview' => 'Tartalomjegyzék',
  'Password' => 'Jelszó',
  'Pending approvals' => 'Függő jóváhagyások',
  'Pending user approvals' => 'Függőben lévő felhasználó-jóváhagyások',
  'People' => 'Emberek',
  'Permanently delete' => 'Törölje véglegesen',
  'Permissions' => 'Engedélyek',
  'Post-registration approval required' => '',
  'Prioritised User Group' => 'Kiemelt felhasználói csoport',
  'Profile Permissions' => 'Profilengedélyek',
  'Profiles' => 'Profilok',
  'Protected' => 'Védett',
  'Protected group can not be deleted!' => 'A védett csoport nem törölhető!',
  'Remove from group' => 'Eltávolítás a csoportból',
  'Resend invitation email' => 'Meghívó e-mail újraküldése',
  'Save' => 'Mentés',
  'Search by name, email or id.' => 'Keresés név, email vagy azonosító szerint.',
  'Select Groups' => 'Csoportok kiválasztása',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => 'Válassz egy prioritást élvező csoportot, amelynek tagjai az összes többi előtt jelennek meg, ha az „Alapértelmezett” rendezési beállítást választja. A csoporton belüli és a csoporton kívüli felhasználók az utolsó bejelentkezési adataik szerint vannak rendezve.',
  'Select the profile fields you want to add as columns' => 'Válaszd ki az oszlopként hozzáadni kívánt profilmezőket',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => 'Válaszd ki, hogy mely felhasználói adatok jelenjenek meg a „Személyek” áttekintésben. Bármilyen profilmezőt kiválaszthatod, még azokat is, amelyeket egyedileg hoztál létre.',
  'Send' => 'Küldés',
  'Send & decline' => 'Küldés és elutasítás',
  'Send & save' => 'Küldés és mentés',
  'Send a message' => '',
  'Send a message to <strong>{displayName}</strong> ' => '',
  'Send invitation email' => 'Meghívó e-mail küldése',
  'Send invitation email again?' => 'Meghívólevél újraküldése?',
  'Send notifications to users when added to or removed from the group.' => 'Értesítéseket küldése a felhasználóknak, ha felveszik őket a csoportba vagy eltávolítják őket.',
  'Settings' => 'Beállítások',
  'Show group selection at registration' => 'Csoportválasztás megjelenítése a regisztrációkor',
  'Subject' => 'Téma',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Az összes csoporttag területi tagsága frissül. Ez akár néhány percet igénybe vehet.',
  'The following list contains all pending sign-ups and invites.' => 'Az alábbi lista tartalmazza az összes folyamatban lévő feliratkozást és meghívást.',
  'The following list contains all registered users awaiting an approval.' => 'Az alábbi lista tartalmazza a jóváhagyásra váró regisztrált felhasználókat.',
  'The message has been sent by email.' => '',
  'The registration was approved and the user was notified by email.' => 'A regisztrációt jóváhagyták, és a felhasználót e-mailben értesítették.',
  'The registration was declined and the user was notified by email.' => 'A regisztrációt elutasították, és a felhasználót e-mailben értesítették.',
  'The registrations were approved and the users were notified by email.' => 'A regisztrációkat jóváhagyták, és a felhasználókat e-mailben értesítették.',
  'The registrations were declined and the users were notified by email.' => 'A regisztrációkat elutasították, és a felhasználókat e-mailben értesítették.',
  'The selected invitations have been successfully deleted!' => 'A kiválasztott meghívókat sikeresen töröltük!',
  'The user is the owner of these spaces:' => 'A felhasználó tulajdonosa ezeknek a közösségeknek:',
  'The users were notified by email.' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Ez az opció lehetővé teszi annak meghatározását, hogy a felhasználók beállíthatnak-e egyedi engedélyeket a saját profiljukhoz.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Ez az áttekintés tartalmazza az egyes regisztrált felhasználók listáját, a következő opciókkal: felhasználó megtekintése, felhasználó szerkesztése, felhasználó törlése.',
  'This user owns no spaces.' => 'Ez a felhasználó nem tulajdonosa egyetlen közösségnek sem.',
  'Unapproved' => 'Nincs elfogadva',
  'User deletion process queued.' => 'A felhasználó törlési folyamata sorban áll.',
  'User is already a member of this group.' => 'A felhasználó már tagja ennek a csoportnak',
  'User not found!' => 'A felhasználó nem található!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'A felhasználók különböző csoportokhoz (pl. csapatok, osztályok stb.) rendelhetők,  amelyek saját szabványos közösségekkel, csoport adminokkal és engedélyekkel rendelkeznek.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Ennek az opciónak a használatával visszavonhatatlanul törlődnek a felhasználó hozzájárulásai (például tartalmai, megjegyzései vagy kedvelései).',
  'View profile' => 'Profil törlése',
  'Visible for members only' => 'Csak a tagok számára látható',
  'Visible for members+guests' => 'A tagok és vendégek számára is látható',
  'Will be used as a filter in \'People\'.' => 'Szűrőként lesz használva az „Emberek” részben.',
  'Yes' => 'Igen',
  'You can only delete empty categories!' => 'Csak üres kategóriák törölhetők!',
  'You cannot delete yourself!' => 'Nem törölheted saját magad!',
  'never' => 'soha',
  '{nbMsgSent} already sent' => '',
);
